/* -*- Mode: indent-tabs-mode: nil; js-indent-level: 2 -*- */
/* vim: set sts=2 sw=2 et tw=80: */
"use strict";

const kBackgrounds = [
  "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAUAAAAFCAYAAACNbyblAAAAHElEQVQI12P4//8/w38GIAXDIBKE0DHxgljNBAAO9TXL0Y4OHwAAAABJRU5ErkJggg==",
  "data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNiIgaGVpZ2h0PSIxNiIgdmlld0JveD0iMCAwIDE2IDE2Ij4KICA8cGF0aCBkPSJNOCwxMkwzLDcsNCw2bDQsNCw0LTQsMSwxWiIgZmlsbD0iIzZBNkE2QSIgLz4KPC9zdmc+Cg==",
];

add_task(function* testAboutHomeBackground() {
  let tab = yield BrowserTestUtils.openNewForegroundTab(gBrowser, "about:home", true);

  let extension = ExtensionTestUtils.loadExtension({
    manifest: {
      "theme": {
        "images": {
          "theme_ntp_background": kBackgrounds[0]
        }
      }
    },
    background() {
      browser.test.onMessage.addListener((message, data) => {
        if (message === "update-theme") {
          browser.theme.update(data);
          browser.test.sendMessage("theme-updated");
        }
      });
    }
  });

  yield extension.startup();

  let win = tab.linkedBrowser.contentWindow;
  let docEl = win.document.documentElement;
  let background = win.getComputedStyle(docEl).backgroundImage;
  is(background, `url("` + kBackgrounds[0] + `")`, "Expected background image");

  extension.sendMessage("update-theme", {
    "images": {
      "theme_ntp_background": kBackgrounds[1],
    }
  });

  yield extension.awaitMessage("theme-updated");

  background = win.getComputedStyle(docEl).backgroundImage;
  is(background, `url("` + kBackgrounds[1] + `")`, "Expected background image");

  yield extension.unload();

  background = win.getComputedStyle(docEl).backgroundImage;
  is(background, "none", "The background image should be cleared when the extension is unloaded");

  yield BrowserTestUtils.removeTab(tab);
});
